@@ -4,6 +4,7 @@ from ui.ImageButton import ImageButton
 from ui.Label import Label
 from ui.itemview import ThumbableGridView
 from ui.Slider import VSlider
+from ui.dialog import InfoDialog
 from ui.dialog import InputDialog
 from ui.dialog import OptionDialog
 from ui.dialog import ListDialog
@@ -14,8 +15,11 @@ from StationItem import StationItem
 from FMScala import FMScala
 from FMRadio import *
 import rdsdecode
-from SoundPipe import SoundPipe
 import platforms
+if (platforms.MAEMO5):
+    from SoundPipe import SoundPipe
+else:
+    from SoundPipeN800 import SoundPipe
 import values
 from theme import theme
 import config
@@ -181,12 +185,8 @@ class FMRadioUI(Component, Window):
         Displays a banner note with the given message string.
         """
           
-        try:
-            import hildon
-            hildon.hildon_banner_show_information(self.get_gtk_window(),
-                                                  "", msg)
-        except:
-            print msg
+        dlg = InfoDialog(msg, self)
+        dlg.run()
 
 
 
@@ -210,10 +210,11 @@ class FMRadioUI(Component, Window):
         x, y = self.get_screen_pos()
         w, h = self.get_size()
         screen = self.get_screen()
+        print x, y, w, h
         
-        screen.draw_pixbuf(theme.top, 0, 0)
+        screen.draw_pixbuf(theme.top, x, y)
         self.__lbl_rds.set_geometry(10, 0, w - 20, 0)
-        self.__fmscala.set_geometry(81, 28, 638, 270)
+        self.__fmscala.set_geometry(81, 0 + 28, 638, 270)
         self.__btn_prev.set_geometry(0, 28, 81, 270)
         self.__btn_next.set_geometry(w - 81, 28, 81, 270)
         
@@ -226,7 +227,7 @@ class FMRadioUI(Component, Window):
         w, h = self.get_size()
         screen = self.get_screen()
         
-        screen.draw_pixbuf(theme.bottom, 0, h - 125)
+        screen.draw_pixbuf(theme.bottom, x, y + h - 125)
                 
         self.__lbl_station.set_geometry(0, h - 100, w, 0)
         self.__lbl_freq.set_geometry(0, h - 60, w, 0)
@@ -235,7 +236,7 @@ class FMRadioUI(Component, Window):
         #t_w, t_h = text_extents(self.__lbl_station.get_text(),
         #                        theme.font_rds_name)
         screen.draw_pixbuf(theme.bt_rdsname_arrow,
-                           w - 64, h - 64)
+                           x + w - 64, y + h - 64)
 
         
 
@@ -462,7 +463,7 @@ class FMRadioUI(Component, Window):
             self.__display_note("You don't have stations saved")
             return
     
-        self.__stations.sort(lambda a,b:cmp(a[1], b[1]))
+        self.__stations.sort(lambda a,b:cmp(a[1].lower(), b[1].lower()))
 
         dlg = ListDialog("Stations")
         for freq, name in self.__stations:
@@ -470,9 +471,9 @@ class FMRadioUI(Component, Window):
             dlg.add_item(item)
         #end for
         
-        ret = dlg.run()
-        if (ret == 0):
-            item = dlg.get_choice()
+        dlg.run()
+        item = dlg.get_choice()
+        if (item):
             freq = item.get_frequency()
             self.__fmscala.set_value(freq)
         #end if
@@ -518,7 +519,7 @@ class FMRadioUI(Component, Window):
         if (self.__device == "RX-51"):
             ret, dev = platforms.request_fmradio()
         else:
-            ret = 1
+            ret = 0
 
         print "return code from FMRX-Enabler:", ret
 
@@ -541,8 +542,13 @@ class FMRadioUI(Component, Window):
             self.__keep_alive_handler = gobject.timeout_add(15000,
                                                     self.__keep_radio_alive)
             self.__rds_handler = gobject.timeout_add(500, self.__update_rds)
+
+        else:
+            self.__radio.set_frequency(self.__fmscala.get_value())
+
         #end if
 
+
         self.__sound_pipe.on()
         self.__sound_pipe.use_speaker(self.__use_speaker)
         
@@ -726,9 +732,10 @@ class FMRadioUI(Component, Window):
     def handle_SYSTEM_EV_HEADPHONES_INSERTED(self):
     
         self.__have_headphones = True
-        # become active only after the policy decision was broadcast, or the
-        # policy will override the our settings...
-        #self.__end_interruption()
+
+        # on Maemo 5, the policy daemon will end the interruption
+        if (platforms.MAEMO4):
+            self.__end_interruption()
         
         
     def handle_SYSTEM_EV_HEADPHONES_REMOVED(self):
