@@ -20,7 +20,7 @@ class Button(ImageButton):
         """
     
         self.__label = text
-        #self.render()
+        self.render()
 
 
     def _render_content(self, cnv):
@@ -28,5 +28,5 @@ class Button(ImageButton):
         w, h = self.get_size()
 
         cnv.draw_centered_text(self.__label, theme.font_mb_plain,
-                               0, 0, w, h, "#ffffff")
+                               0, 0, w, h, theme.color_ui_button_text)
 
