@@ -14,8 +14,8 @@ class ListDialog(Window):
         
     
         Window.__init__(self, Window.TYPE_DIALOG)
+        self.connect_closed(self.__on_close)
         self.set_title(title)
-        self.get_gtk_window().set_size_request(800, 320)
 
         self.__list = ThumbableGridView()
         self.add(self.__list)
@@ -34,10 +34,15 @@ class ListDialog(Window):
         self.__list.set_geometry(40, 0, w - 40, h)
 
 
+    def __on_close(self):
+    
+        self.destroy()
+
+
     def __on_click_item(self, item):
     
         self.__choice = item
-        self.get_gtk_window().response(gtk.RESPONSE_ACCEPT)
+        self.set_visible(False)
 
 
     def add_item(self, item):
@@ -46,21 +51,7 @@ class ListDialog(Window):
         self.__list.append_item(item)
 
 
-
     def get_choice(self):
     
         return self.__choice
 
-
-    def run(self):
-    
-        win = self.get_gtk_window()
-    
-        self.set_visible(True)
-        resp = win.run()
-        win.destroy()
-        
-        if (resp == gtk.RESPONSE_ACCEPT):
-            return 0
-        else:
-            return 1
